==> nextcloud-25.0.4.tgz: nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info om prosessor er ikke tilgjengelig",
    "Load average: {cpu} (last minute)" : "Gjennomsnittslast: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Minne: Totalt: {memTotalBytes}/Nåværende bruk: {memUsageBytes}",
    "RAM info not available" : "Info om minne er ikke tilgjengelig",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totalt: {swapTotalBytes}/Nåværende bruk: {swapUsageBytes}",
    "SWAP info not available" : "Info om SWAP er ikke tilgjengelig",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "Unknown Processor" : "Ukjent prosessor",
    "Temperature" : "Temperatur",
    "Load" : "Last",
    "Memory" : "Minne",
    "Disk" : "Disk",
    "Size:" : "Størrelse:",
    "You will get a notification once one of your disks is nearly full." : "Du vil motta et varsel når en av diskene dine er nesten full.",
    "Files:" : "Filer:",
    "Network" : "Nettverk",
    "Active users" : "Aktive brukere",
    "Shares" : "Delinger",
    "Users:" : "Brukere:",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "Copy" : "Kopier",
    "Users" : "Brukere",
    "Groups" : "Grupper",
    "Links" : "Lenker",
    "Emails" : "E-poster",
    "Federated sent" : "«Forent sendt» - delingen sendt eksternt",
    "Federated received" : "«Forent mottatt» - en ekstern deling mottatt",
    "Talk conversations" : "Talk-samtaler",
    "24 hours" : "24 timer",
    "1 hour" : "1 time",
    "5 mins" : "5 minutter",
    "Copied!" : "Kopiert!",
    "Operating System" : "Operativsystem",
    "CPU" : "CPU",
    "Server time" : "Server tid",
    "Uptime" : "Oppetid",
    "Filesystem" : "Filsystem",
    "Size" : "Størrelse",
    "Available" : "Tilgjengelig",
    "Used" : "Brukt",
    "Files" : "Filer",
    "Storages" : "Lagringer",
    "Free Space" : "Ledig plass",
    "Hostname" : "Servernavn",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Fart",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Version" : "Versjon",
    "Memory limit" : "Minnegrense",
    "Type" : "Type"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12p1.tgz: nextcloud/apps/serverinfo/l10n/nb.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Info om prosessor er ikke tilgjengelig",
    "Load average: {cpu} (last minute)" : "Gjennomsnittslast: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Minne: Totalt: {memTotalBytes}/Nåværende bruk: {memUsageBytes}",
    "RAM info not available" : "Info om minne er ikke tilgjengelig",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Totalt: {swapTotalBytes}/Nåværende bruk: {swapUsageBytes}",
    "SWAP info not available" : "Info om SWAP er ikke tilgjengelig",
    "Not supported!" : "Ikke støttet!",
    "Press ⌘-C to copy." : "Trykk ⌘-C for å kopiere.",
    "Press Ctrl-C to copy." : "Trykk Ctrl-C for å kopiere.",
    "System" : "System",
    "Monitoring" : "Overvåker",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Gir nyttig serverinformasjon, som CPU-belastning, RAM-bruk, diskbruk, antall brukere, ned mere.",
    "Operating System:" : "Operativsystem:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Ukjent prosessor",
    "Memory:" : "Minne:",
    "Server time:" : "Servertid:",
    "Uptime:" : "Oppetid:",
    "Temperature" : "Temperatur",
    "Load" : "Last",
    "Memory" : "Minne",
    "Disk" : "Disk",
    "Mount:" : "Montering:",
    "Filesystem:" : "Filsystem:",
    "Size:" : "Størrelse:",
    "Available:" : "Tilgjengelig:",
    "Used:" : "Brukt:",
    "Files:" : "Filer:",
    "Storages:" : "Lagringer:",
    "Free Space:" : "Ledig plass:",
    "Network" : "Nettverk",
    "Hostname:" : "Servernavn:",
    "DNS:" : "DNS:",
    "Gateway:" : "Standardruter:",
    "Status:" : "Status:",
    "Speed:" : "Hastighet:",
    "Duplex:" : "Duplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktive brukere",
    "Total users:" : "Totalt antall brukere:",
    "24 hours:" : "24 timer:",
    "1 hour:" : "1 time:",
    "5 mins:" : "5 minutter:",
    "Shares" : "Delinger",
    "Users:" : "Brukere:",
    "Groups:" : "Grupper:",
    "Links:" : "Lenker:",
    "Emails:" : "E-poster:",
    "Talk conversations:" : "Talk-samtaler:",
    "PHP" : "PHP",
    "Version:" : "Versjon:",
    "Memory limit:" : "Minnegrense:",
    "Max execution time:" : "Maks. kjøringstid:",
    "Upload max size:" : "Maks. opplastingstørrelse:",
    "Database" : "Database",
    "Type:" : "Type:",
    "External monitoring tool" : "Eksternt overvåkingsverktøy",
    "Copy" : "Kopier",
    "You will get a notification once one of your disks is nearly full." : "Du vil motta et varsel når en av diskene dine er nesten full."
},
"nplurals=2; plural=(n != 1);");
